from .speakers import Darshika
from pathlib import Path

def main():
    Darshika().print_name()
    # with open("names.txt") as f:
    with (Path(__file__).parent / "names.txt").open() as f:
        print(f.read())

if __name__ == "__main__":
    main()


from colorama import init as coloarama_init
from colorama import Fore
class Speaker:
    name = ""
    def __init__(self):
        coloarama_init()
    def print_name(self):
        print(f"Hi my name is {Fore.GREEN}{self.name}!")
        